@@ -17,7 +17,7 @@ from rich.syntax import Syntax
 from .__init__ import __version__ as VERSION
 from .utils import (MofNCompleteColumn, StatefulColumn, Time, TIME_FORMAT_UNITS,
                     get_code_input, choose_unit, format_snippet, make_bar_plot,
-                    _Timer as Timer
+                    _Timer as Timer, factors
                     )
 from .exporter import Exporter
 
@@ -91,6 +91,8 @@ console.stateful_data = {}
 console.exporter = Exporter(console=console, alt_console=alt_console)
 # Setting the color profile to the one from rich. To be consistent.
 set_prompt_toolkit_color()
+# Defining an infinity constant
+INFINITY = float('inf')
 
 
 @click.command()
@@ -440,9 +442,8 @@ def app(
                     timer.timeit(number=1)
                     progress.update(warmup_task, advance=1)
                 progress.remove_task(warmup_task)
-            initial_task = progress.add_task("Calculating amount of runs…", total=1, start=False)
 
-            def _autorange(timer: Timer, callback=None):
+            def _autorange(timer: Timer, callback=None, max_number=INFINITY):
                 # This is a custom timeit.autorange implementation for lower time_taken.
                 # This is done to make the progress bar more smoother.
                 # This does have one drawback where it makes it slower if there is a long setup
@@ -455,6 +456,8 @@ def app(
                 while True:
                     for j in 1, 2, 5, 8:
                         number = i * j
+                        if number > max_number:
+                            return number, time_taken
                         time_taken = timer.timeit(number)
                         if callback:
                             callback(number, time_taken)
@@ -463,16 +466,17 @@ def app(
                             return (number, time_taken)
                     i *= 10
 
-            # determine number so that 0.1 <= total time < 2.0
-            try:
-                num_in_one_batch, time_taken = _autorange(timer, autorange_callback)
-            except Exception:
-                timer.print_exc()
-                raise click.exceptions.Exit()
-            progress.remove_task(initial_task)
 
             # Logic for calculating number of total runs
             if not runs:
+                initial_task = progress.add_task("Calculating amount of runs…", total=1, start=False)
+                # determine number so that 0.1 <= total time < 2.0
+                try:
+                    num_in_one_batch, time_taken = _autorange(timer, autorange_callback)
+                except Exception:
+                    timer.print_exc()
+                    raise click.exceptions.Exit()
+                progress.remove_task(initial_task)
                 num_of_batches = int(total_time / time_taken)
                 total_runs_based_on_time = num_of_batches * num_in_one_batch
                 if (total_runs_based_on_time) < min_runs:
@@ -480,12 +484,28 @@ def app(
                 if max_runs and (total_runs_based_on_time) > max_runs:
                     num_of_batches = max_runs // num_in_one_batch
             else:
+                with console.status("Calculating amount of runs…"):
+                    # determine number so that 0.1 <= total time < 2.0
+                    try:
+                        num_in_one_batch, time_taken = _autorange(timer, autorange_callback, max_number=runs)
+                    except Exception:
+                        timer.print_exc()
+                        raise click.exceptions.Exit()
                 if runs > num_in_one_batch:
                     num_of_batches = runs // num_in_one_batch
                 else:
-                    # Do it in three batches to get better statistics
-                    num_of_batches = 3
-                    num_in_one_batch = ceil(runs / 3)
+                    if runs < 3:
+                        # If there are less than 3 runs then we can probably do it in one batch
+                        num_of_batches = 1
+                        num_in_one_batch = 1
+                    else:
+                        # Otherwise, we try to do it in 3 batches
+                        num_of_batches = 3
+                        num_in_one_batch = ceil(runs / 3)
+                        # If it's not divisible by 3 then we try 2
+                        if (num_of_batches * num_in_one_batch) != runs:
+                            num_of_batches = 2
+                            num_in_one_batch = ceil(runs / 2)
             total_runs = num_of_batches * num_in_one_batch
 
             # Start the actual benchmarking process
@@ -500,14 +520,17 @@ def app(
             timings = [time_taken_for_entire_batch / num_in_one_batch for time_taken_for_entire_batch in raw_timings]
 
         # Calculate mean, median, standard_deviation, min, max
-        mean = statistics.mean(timings)
-        median = statistics.median(timings)
         _min = min(timings)
         _max = max(timings)
-        try:
+        # If there aren't enough data then we just make the statistics -1
+        if len(timings) < 2:
+            # In an ideal world I would like to use "?" but
+            # it would probably mess something else up now.
+            mean = median = standard_deviation = -1
+        else:
+            mean = statistics.mean(timings)
+            median = statistics.median(timings)
             standard_deviation = statistics.stdev(timings)
-        except statistics.StatisticsError:
-            standard_deviation = -1
 
         # Add the statistics to a exporter class to keep track of them
         console.exporter.add_result(
