@@ -101,7 +101,7 @@ class Exporter:
             with open(filename, "w", encoding="utf-8") as f:
                 json.dump(
                     {
-                        "$schema": "https://api.jsonbin.io/b/625164e2d8a4cc06909e3be7/5",
+                        "$schema": "https://raw.githubusercontent.com/wasi-master/fastero/main/schema.json",
                         "setup": self.setup,
                         "results": self.snippets,
                     },
@@ -621,7 +621,8 @@ class Exporter:
                 from PIL import Image, ImageChops
             except ImportError:
                 self.alt_console.print(
-                    "[red b]Error:[/] The package [#bbbbbb on #222222]Pillow[/] is not installed. Please install it in order to export images."
+                    "[red b]Error:[/] The package [#bbbbbb on #222222]Pillow[/] is not installed. Please install it in order to export images. "
+                    f"An uncropped version of your image is saved in [yellow]{png_file_location}[/]"
                 )
                 raise click.exceptions.Exit()
 
